@@ -141,10 +141,10 @@ function [CC]=train_sc(D,classlabel,MODE,W)
 %       Machine Learning 285-318(2)
 % 	http://en.wikipedia.org/wiki/Winnow_(algorithm)
  
-%	$Id: train_sc.m 7518 2010-08-12 21:02:22Z schloegl $
-%	Copyright (C) 2005,2006,2007,2008,2009,2010 by Alois Schloegl <a.schloegl@ieee.org>
+%	$Id: train_sc.m 8223 2011-04-20 09:16:06Z schloegl $
+%	Copyright (C) 2005,2006,2007,2008,2009,2010 by Alois Schloegl <alois.schloegl@gmail.com>
 %       This function is part of the NaN-toolbox
-%       http://biosig-consulting.com/matlab/NaN/
+%       http://pub.ist.ac.at/~schloegl/matlab/NaN/
 
 % This program is free software; you can redistribute it and/or
 % modify it under the terms of the GNU General Public License
@@ -619,10 +619,6 @@ elseif ~isempty(strfind(lower(MODE.TYPE),'psvm'))
         
 
 elseif ~isempty(strfind(lower(MODE.TYPE),'svm:lin4'))
-	if ~isempty(W) 
-%		error('Classifier (%s) does not support weighted samples.',MODE.TYPE);
-	end; 	
-
         if ~isfield(MODE.hyperparameter,'c_value')
                 MODE.hyperparameter.c_value = 1; 
         end
@@ -677,10 +673,6 @@ elseif ~isempty(strfind(lower(MODE.TYPE),'svm'))
                 error('No SVM training algorithm available. Install OSV-SVM, or LOO-SVM, or libSVM for Matlab.\n');
         end;
 
-	if ~strncmp(MODE.TYPE, 'SVM:LIN',7) && ~isempty(W) 
-		error('Classifier (%s) does not support weighted samples.',MODE.TYPE);
-	end; 	
-                
         %%CC = train_svm(D,classlabel,MODE);
 	[CL101,CC.Labels] = cl101(classlabel); 
 	M = size(CL101,2);
@@ -694,7 +686,7 @@ elseif ~isempty(strfind(lower(MODE.TYPE),'svm'))
         s(1,:) = -m.*r; 
 
         for k = 1:M,
-                cl = CL101(:,k);
+                cl = CL101(rix,k);
                 if strncmp(MODE.TYPE, 'SVM:LIN',7);
                         if isfield(MODE,'options')
                                 CC.options = MODE.options;
